import 'package:webview_flutter/webview_flutter.dart';
import 'package:flutter/material.dart';

import 'dart:convert';
import 'dart:io' show Platform;
import 'package:flutter/foundation.dart' show kIsWeb;
import 'package:svgator_player_flutter/svgator_player_flutter.dart';

class Locationindicatorsample extends StatefulWidget {
    final double? width;
    final double? height;
    
    final Function? onMessage;
    

    Locationindicatorsample({
        Key? key,
        this.width,
        this.height,
      
        this.onMessage,
      
    }): super(key: key);

  @override
  LocationindicatorsampleState createState() => new LocationindicatorsampleState();
}

class LocationindicatorsampleState extends State<Locationindicatorsample> {
  final _key = UniqueKey();
  
  WebViewController? _SVGatorController;
  void runCommand(String command, int? param) {
      SVGatorPlayer.runCommand(_SVGatorController, command, param);
  }
  

  @override
  Widget build(BuildContext context) {
    if (kIsWeb || (!Platform.isAndroid && !Platform.isIOS)) {
      debugPrint("SVGator's Flutter animations run only on Android or iOS!");
      return SizedBox.shrink();
    }
    return Container(
        width: this.widget.width,
        height: this.widget.height,
        child: WebView(
          key: _key,
          javascriptMode: JavascriptMode.unrestricted,
          initialUrl: 'about:blank',
          
          javascriptChannels: <JavascriptChannel>{
            JavascriptChannel(
              name: 'SVGatorFlutterChannel',
              onMessageReceived: (JavascriptMessage message) {
                if (widget.onMessage != null) {
                  widget.onMessage?.call(message.message);
                }
              },
            )
          },
          
          onWebViewCreated: (WebViewController webViewController) {
            
            _SVGatorController = webViewController;
            
            _loadHtmlFromAssets(webViewController);
          },
          onPageFinished: (String url) {
            if (url == 'about:blank') {
              return;
            }
            
            _SVGatorController?.evaluateJavascript(SVGatorPlayer.initPlayer());
            
          },
        )
    );
  }

  _loadHtmlFromAssets(webViewController) async {
    String Svg = "<svg id=\"eirFfTVU8zw1\" xmlns=\"http:\/\/www.w3.org\/2000\/svg\" xmlns:xlink=\"http:\/\/www.w3.org\/1999\/xlink\" viewBox=\"0 0 480 435\" shape-rendering=\"geometricPrecision\" text-rendering=\"geometricPrecision\"><defs><linearGradient id=\"eirFfTVU8zw32-fill\" x1=\"0.5\" y1=\"0.001867\" x2=\"0.5\" y2=\"1\" spreadMethod=\"pad\" gradientUnits=\"objectBoundingBox\" gradientTransform=\"translate(0 0)\"><stop id=\"eirFfTVU8zw32-fill-0\" offset=\"0%\" stop-color=\"#329bee\"\/><stop id=\"eirFfTVU8zw32-fill-1\" offset=\"100%\" stop-color=\"#2f6bd9\"\/><\/linearGradient><\/defs><g transform=\"matrix(.71626 0 0 0.71626-20.120748 83.968142)\"><g><path d=\"M693.44,439.82L573,207.63c-4-7.69-21.69-13.72-39.67-13.72h-337c-18,0-35.68,6-39.67,13.72L36.24,439.82C25.77,460,42,477.31,73.14,477.31h583.4c31.12,0,47.36-17.31,36.9-37.49Z\" fill=\"#f2f0ee\"\/><path d=\"M421.52,228.06c58.19-12.58,104.48-11.52,161.61-.9l-10-19.23-.16-.3c-4-7.69-21.69-13.72-39.67-13.72h-319.84c35.8,2.47,59.16,10.7,80.08,23.39c34.28,20.8,80.32,21.06,127.98,10.76Z\" fill=\"#d1e1f9\"\/><path d=\"M455.13,228.06c41.09-3.28,84.49-4.31,120.33-2.28-4.84-6.05-20.25-13.36-37.87-13.56-25-.28-25.42,4.71-46.89,5.6s-30-3.13-47.87.59c-18.05,3.76-1,9.74-55.27,15.07c0,0,18.94,23.74-23.82,44.92l-89.07,44.11v0c-8.9-5.88-22.59-9.38-38.58-9-27.15.62-53.1,12.84-59,28.4-6.63,17.61,13.94,32.85,46,32.85c16.8,0,32.73-4.27,44.33-10.94v0l56.39,36.78c41.1,26.81,99,19.82,127.85,0L599.92,298.78C495.61,275,464.8,241.49,455.13,228.06Z\" fill=\"#cadfaa\"\/><polygon points=\"111.27,400.92 73.21,368.53 37.55,437.28 111.27,400.92\" fill=\"#cadfaa\"\/><polygon points=\"207.47,261.69 231.6,249.91 152.84,215.01 131.71,255.75 152.24,267.64 189.75,252.44 207.47,261.69\" fill=\"#ebe8e1\"\/><polygon points=\"124.66,394.53 152.58,380.75 91.48,333.31 79.21,356.97 124.66,394.53\" fill=\"#ebe8e1\"\/><path d=\"M180.59,402.5L47.73,472.22c6.59,3.22,15.19,5.09,25.41,5.09h63.49l81-46.05Z\" fill=\"#ebe8e1\"\/><polygon points=\"496.93,477.31 447.75,446.87 406.45,477.31 496.93,477.31\" fill=\"#ebe8e1\"\/><polygon points=\"553.13,354.58 489.32,399.22 546.91,430.94 577.65,406 636.02,436.06 666.72,409.2 553.13,354.58\" fill=\"#ebe8e1\"\/><polygon points=\"482.72,403.95 442.38,432.85 515.44,477.31 614.05,477.31 482.72,403.95\" fill=\"#ebe8e1\"\/><\/g><path d=\"M550.67,347.07l-86.21,60.84c-19.29,13.64-46.98,20.64-75.6,20.64-22.71,0-45.27-4.45-63.86-13.17-8.82,8-14.1,17.59-15,28-.99967,12.01603,3.88677,23.85217,14.21974,33.93h-42.86527c-5.70358-10.3314-7.92497-22.22625-6.33448-33.92c2.27-16.08,11.69-30.64,26.57-42.23l-37.13-24.85c-13.9589,5.28189-28.76527,7.96934-43.69,7.93-5.44692.00911-10.8875-.37186-16.28-1.14L40.96517,467.88598c-6.69434-5.66803-9.39956-13.44563-7.08745-22.0735L177.24,374.32c-13.66-7.89-19.7-19.51-15-31.95c3.05-8.08,10.22-15.36,19.82-21.21L119.5,279.29l9.12-17.57l43.09,27.41l110.5-46.65c-9.0554-3.71317-17.69331-8.37234-25.77-13.9-22.02784-15.4135-47.76808-21.11306-98.2609-23.12576c3.05839-3.45842,8.86341-6.44485,16.02197-8.51333c12.51106.63301,23.75343,1.54345,33.99893,2.8491c28.96,3.69,49.85,10.56,68.11,22.76c7.39,5,23.92,14.35,49.23,20c23.82083,5.41608,48.52996,5.62756,72.44.62c47.22-10.06,87.24-14.36,124.07-13.46c22.3894.49888,44.67711,3.17508,66.5481,7.99077l6.73891,12.99158c-23.02022-6.44511-46.76586-9.94055-70.66701-10.40236-33.32-.82-71.7,3.49-115.7,13.13-35.82555,7.69258-73.01101,6.24478-108.13-4.21L187,298.83l19,12.1c11.13249-3.15757,22.64837-4.75942,34.22-4.76c35.46,0,62.42,15.61,59.94,36.2-.89,7.32-5.36,14.35-12.5,20.53l48.08,30.59c28.51,18.14,76.39,18.14,103.51,0L610.11424,279.18061l9.85201,18.99318-52.77626,37.2162l94.56,43.34l4.99863,9.63311l9.54676,18.4047L550.67,347.07Zm-279.96-4.7c2.11-11.99-13.27-21.36-34.19-21.36s-40.96,9.36-44.84,21.36c-4.05,12.56,11,23.21,33.73,23.21s43.1-10.65,45.3-23.21Z\" fill=\"#fff\"\/><g id=\"eirFfTVU8zw15\" clip-path=\"url(#eirFfTVU8zw18)\"><g><path id=\"eirFfTVU8zw17\" d=\"M29.720526,459.598725L203.14,372.49c6.55256,1.549972,13.266748,2.312032,20,2.27c27.31,0,40.35-8.82,44.33-10.94l56.39,36.78c35.09,22.89,94.53,22.89,127.85,0L547,335.15l-12-5.56-26.41-12.32c-22.34-10.42-53.8-10.42-71.74,0L372.4,354.51\" fill=\"none\" stroke=\"#02db86\" stroke-width=\"26\" stroke-linecap=\"round\" stroke-miterlimit=\"10\" stroke-dashoffset=\"768.55\" stroke-dasharray=\"768.55\"\/><\/g><clipPath id=\"eirFfTVU8zw18\"><path d=\"M461.18,308.89c4.18,3.67,2.24,8.2-4.44,10.09l-.3.09c-7.39,2.14-16,0-19.64-3.32-4.06-3.7-1.94-8.16,4.63-10l.5-.14c6.56-1.79,15.13-.34,19.25,3.28ZM264.66,376.62L311.51,408c41.69,27.91,113.55,27.91,153.08,0l94.91-67c5.47-3.87,1.18-9.08-4.21-11.55L543.4,324c-6.64-3-15.7-3-20.35,0s-3.27,8,3.14,11.16L439.1,393.4c-27.05,18.09-74.78,18.09-103.22,0l-56.49-35.92c-5.41-3.45-15.05-3.45-21.66,0-14.153048,7.952334-30.7948,10.242942-46.57,6.41-5.795706-1.219346-11.832333-.47708-17.16,2.11L34.49,443.86c-3.3,9.4-.7,17.93,6.5,24l163.65-84.63c2.92.44,32.03,4.57,60.02-6.61Zm236.26-70.43c-7.22-1.92-15.33-.63-18.17,2.92s.68,8.19,8.06,10.22l.33.09c7.47,2.09,15.8.71,18.57-2.94s-1-8.16-8.23-10.14ZM404,324.52l-.33.19c-5.43,3.08-5.1,8.16.85,11.34c4.87,2.6,14.44,3.79,20.82,0l.33-.2c5.35-3.17,4.71-8.24-1.3-11.33s-14.98-3.04-20.37,0Zm-35.27,20l-.36.2c-5.86,3.32-5.89,8.8.07,12.24c3.69,2.12,13.77,4.68,21.65,0l.35-.21c5.78-3.43,5.47-8.91-.56-12.24s-15.34-3.24-21.12.04Z\" fill=\"none\"\/><\/clipPath><\/g><g id=\"eirFfTVU8zw20\"><path d=\"M400.42,366c.24,3.84-15.69,7-35.58,7s-35.83-3.14-35.59-7s16.17-6.8,35.59-6.8s35.34,3.03,35.58,6.8Z\" transform=\"matrix(1.110391 0 0 3.052896-38.900212-757.04721)\" fill=\"#a0b286\"\/><g id=\"eirFfTVU8zw22\"><path id=\"eirFfTVU8zw23\" d=\"M400.42,366c.24,3.84-15.69,7-35.58,7s-35.83-3.14-35.59-7s16.17-6.8,35.59-6.8s35.34,3.03,35.58,6.8Z\" transform=\"matrix(0 0 0 0 366.209313 360.618034)\" fill=\"#02db86\"\/><\/g><\/g><path d=\"M696.61,451.75c0,14.62-15.34,25.56-40.07,25.56h-583.4c-24.74,0-40.07-10.94-40.07-25.56v12.78c0,14.62,15.33,25.56,40.07,25.56h583.4c24.73,0,40.07-10.94,40.07-25.56Z\" fill=\"#d9d1c7\"\/><\/g><g transform=\"matrix(3.4 0 0 3.4-950-131.675255)\"><g id=\"eirFfTVU8zw26\" transform=\"matrix(.8 0 0 0.8 70 28.000007)\"><rect id=\"eirFfTVU8zw27\" width=\"7.5\" height=\"30.46646\" rx=\"0\" ry=\"0\" transform=\"matrix(.65 0 0 1 341.973713 65.033217)\" opacity=\"0\" fill=\"#1859d0\" stroke-width=\"0\"\/><rect id=\"eirFfTVU8zw28\" width=\"7.5\" height=\"30.46646\" rx=\"0\" ry=\"0\" transform=\"matrix(.65 0 0 1 355.3625 65.033217)\" opacity=\"0\" fill=\"#1859d0\" stroke-width=\"0\"\/><rect id=\"eirFfTVU8zw29\" width=\"7.5\" height=\"45.037221\" rx=\"0\" ry=\"0\" transform=\"matrix(0 0 0 1 350 94.96278)\" fill=\"#1859d0\" stroke-width=\"0\"\/><rect id=\"eirFfTVU8zw30\" width=\"7.5\" height=\"5\" rx=\"0\" ry=\"0\" transform=\"matrix(0 0 0 3.015753 350 49.999998)\" fill=\"#1859d0\" stroke-width=\"0\"\/><path id=\"eirFfTVU8zw31\" d=\"M350,50c16.56854,0,30,13.43146,30,30c0,25-20,35-29,59c0,.55228-.44772,1-1,1s-1-.44772-1-1c-9-25-29-34-29-59c0-16.56854,13.43146-30,30-30Zm0,44.93643c8.24916,0,14.93643-6.68727,14.93643-14.93643s-6.68727-14.93643-14.93643-14.93643-14.93643,6.68727-14.93643,14.93643s6.68727,14.93643,14.93643,14.93643Z\" fill=\"#1859d0\" stroke-width=\"0\"\/><path id=\"eirFfTVU8zw32\" d=\"M350,50c16.56854,0,30,13.43146,30,30c0,25-20,35-29,59c0,.55228-.44772,1-1,1s-1-.44772-1-1c-9-25-29-34-29-59c0-16.56854,13.43146-30,30-30Zm0,44.93643c8.24916,0,14.93643-6.68727,14.93643-14.93643s-6.68727-14.93643-14.93643-14.93643-14.93643,6.68727-14.93643,14.93643s6.68727,14.93643,14.93643,14.93643Z\" fill=\"url(#eirFfTVU8zw32-fill)\" stroke-width=\"0\"\/><\/g><\/g><script><![CDATA[${SVGatorPlayer.getPlayer("91c80d77")};(function(s,i,o,w,a,b){(a=document.getElementById(i.root)).svgatorPlayer={ready:(function(a){b=[];return function(c){return c?(b.push(c),a.svgatorPlayer):b}})(a)};w[o]=w[o]||{};w[o][s]=w[o][s]||[];w[o][s].push(i);})('91c80d77',{\"root\":\"eirFfTVU8zw1\",\"animations\":[{\"elements\":{\"eirFfTVU8zw15\":{\"opacity\":[{\"t\":2300,\"v\":1},{\"t\":2900,\"v\":0}]},\"eirFfTVU8zw17\":{\"stroke-dashoffset\":[{\"t\":900,\"v\":768.55},{\"t\":1600,\"v\":0}]},\"eirFfTVU8zw20\":{\"transform\":{\"data\":{\"o\":{\"x\":366.209305,\"y\":360.618058,\"type\":\"corner\"},\"t\":{\"x\":-366.209305,\"y\":-360.618058}},\"keys\":{\"s\":[{\"t\":300,\"v\":{\"x\":1,\"y\":1},\"e\":[0.645,0.045,0.355,1]},{\"t\":600,\"v\":{\"x\":0.521108,\"y\":0.521108}},{\"t\":900,\"v\":{\"x\":1,\"y\":1}},{\"t\":2300,\"v\":{\"x\":1,\"y\":1},\"e\":[0.645,0.045,0.355,1]},{\"t\":2600,\"v\":{\"x\":0.521108,\"y\":0.521108}},{\"t\":2900,\"v\":{\"x\":1,\"y\":1}}]}},\"opacity\":[{\"t\":300,\"v\":1,\"e\":[0.645,0.045,0.355,1]},{\"t\":600,\"v\":0.49},{\"t\":900,\"v\":1},{\"t\":2300,\"v\":1,\"e\":[0.645,0.045,0.355,1]},{\"t\":2600,\"v\":0.49},{\"t\":2900,\"v\":1}]},\"eirFfTVU8zw22\":{\"opacity\":[{\"t\":2300,\"v\":1},{\"t\":2900,\"v\":0}]},\"eirFfTVU8zw23\":{\"transform\":{\"data\":{\"o\":{\"x\":366.209313,\"y\":360.618034,\"type\":\"corner\"},\"t\":{\"x\":-364.835022,\"y\":-366.100006}},\"keys\":{\"s\":[{\"t\":900,\"v\":{\"x\":0,\"y\":0},\"e\":[0,0,0.58,1]},{\"t\":1100,\"v\":{\"x\":1.110391,\"y\":3.052896}}]}}},\"eirFfTVU8zw26\":{\"transform\":{\"data\":{\"t\":{\"x\":-350,\"y\":-139.999991}},\"keys\":{\"o\":[{\"t\":300,\"v\":{\"x\":350,\"y\":140,\"type\":\"corner\"},\"e\":[0.645,0.045,0.355,1]},{\"t\":600,\"v\":{\"x\":350,\"y\":110.728012,\"type\":\"corner\"},\"e\":[0.645,0.045,0.355,1]},{\"t\":900,\"v\":{\"x\":350,\"y\":140,\"type\":\"corner\"}},{\"t\":2300,\"v\":{\"x\":350,\"y\":140,\"type\":\"corner\"},\"e\":[0.645,0.045,0.355,1]},{\"t\":2600,\"v\":{\"x\":350,\"y\":110.728012,\"type\":\"corner\"},\"e\":[0.645,0.045,0.355,1]},{\"t\":2900,\"v\":{\"x\":350,\"y\":140,\"type\":\"corner\"}}],\"s\":[{\"t\":200,\"v\":{\"x\":0.8,\"y\":0.8},\"e\":[0.215,0.61,0.355,1]},{\"t\":300,\"v\":{\"x\":0.928982,\"y\":0.710652},\"e\":[0.645,0.045,0.355,1]},{\"t\":600,\"v\":{\"x\":0.8,\"y\":0.8},\"e\":[0.645,0.045,0.355,1]},{\"t\":900,\"v\":{\"x\":0.928982,\"y\":0.710652},\"e\":[0.55,0.055,0.675,0.19]},{\"t\":1000,\"v\":{\"x\":0.8,\"y\":0.8}},{\"t\":2200,\"v\":{\"x\":0.8,\"y\":0.8},\"e\":[0.215,0.61,0.355,1]},{\"t\":2300,\"v\":{\"x\":0.928982,\"y\":0.710652},\"e\":[0.645,0.045,0.355,1]},{\"t\":2600,\"v\":{\"x\":0.8,\"y\":0.8},\"e\":[0.645,0.045,0.355,1]},{\"t\":2900,\"v\":{\"x\":0.928982,\"y\":0.710652},\"e\":[0.55,0.055,0.675,0.19]},{\"t\":3000,\"v\":{\"x\":0.8,\"y\":0.8}}]}}},\"eirFfTVU8zw27\":{\"transform\":{\"data\":{\"t\":{\"x\":-3.75,\"y\":-15.23323}},\"keys\":{\"o\":[{\"t\":500,\"v\":{\"x\":344.411213,\"y\":80.266447,\"type\":\"corner\"}},{\"t\":600,\"v\":{\"x\":350,\"y\":80.266447,\"type\":\"corner\"}},{\"t\":700,\"v\":{\"x\":343.999478,\"y\":80.266447,\"type\":\"corner\"}},{\"t\":2500,\"v\":{\"x\":344.411213,\"y\":80.266447,\"type\":\"corner\"}},{\"t\":2600,\"v\":{\"x\":350,\"y\":80.266447,\"type\":\"corner\"}},{\"t\":2700,\"v\":{\"x\":343.999478,\"y\":80.266447,\"type\":\"corner\"}}],\"s\":[{\"t\":500,\"v\":{\"x\":0.65,\"y\":1}},{\"t\":600,\"v\":{\"x\":1,\"y\":1}},{\"t\":700,\"v\":{\"x\":0.65,\"y\":1}},{\"t\":2500,\"v\":{\"x\":0.65,\"y\":1}},{\"t\":2600,\"v\":{\"x\":1,\"y\":1}},{\"t\":2700,\"v\":{\"x\":0.65,\"y\":1}}]}},\"opacity\":[{\"t\":490,\"v\":0},{\"t\":500,\"v\":1},{\"t\":700,\"v\":1},{\"t\":710,\"v\":0},{\"t\":2490,\"v\":0},{\"t\":2500,\"v\":1},{\"t\":2700,\"v\":1},{\"t\":2710,\"v\":0}],\"fill\":[{\"t\":600,\"v\":{\"t\":\"c\",\"v\":{\"r\":24,\"g\":89,\"b\":208,\"a\":1}}},{\"t\":700,\"v\":{\"t\":\"c\",\"v\":{\"r\":208,\"g\":24,\"b\":67,\"a\":1}}},{\"t\":2600,\"v\":{\"t\":\"c\",\"v\":{\"r\":208,\"g\":24,\"b\":67,\"a\":1}}},{\"t\":2700,\"v\":{\"t\":\"c\",\"v\":{\"r\":24,\"g\":89,\"b\":208,\"a\":1}}}]},\"eirFfTVU8zw28\":{\"transform\":{\"data\":{\"t\":{\"x\":-3.75,\"y\":-15.23323}},\"keys\":{\"o\":[{\"t\":500,\"v\":{\"x\":357.8,\"y\":80.266447,\"type\":\"corner\"}},{\"t\":600,\"v\":{\"x\":350,\"y\":80.266447,\"type\":\"corner\"}},{\"t\":700,\"v\":{\"x\":357.8,\"y\":80.266447,\"type\":\"corner\"}},{\"t\":2500,\"v\":{\"x\":357.8,\"y\":80.266447,\"type\":\"corner\"}},{\"t\":2600,\"v\":{\"x\":350,\"y\":80.266447,\"type\":\"corner\"}},{\"t\":2700,\"v\":{\"x\":357.8,\"y\":80.266447,\"type\":\"corner\"}}],\"s\":[{\"t\":500,\"v\":{\"x\":0.65,\"y\":1}},{\"t\":600,\"v\":{\"x\":1,\"y\":1}},{\"t\":700,\"v\":{\"x\":0.65,\"y\":1}},{\"t\":2500,\"v\":{\"x\":0.65,\"y\":1}},{\"t\":2600,\"v\":{\"x\":1,\"y\":1}},{\"t\":2700,\"v\":{\"x\":0.65,\"y\":1}}]}},\"opacity\":[{\"t\":490,\"v\":0},{\"t\":500,\"v\":1},{\"t\":700,\"v\":1},{\"t\":710,\"v\":0},{\"t\":2490,\"v\":0},{\"t\":2500,\"v\":1},{\"t\":2700,\"v\":1},{\"t\":2710,\"v\":0}],\"fill\":[{\"t\":600,\"v\":{\"t\":\"c\",\"v\":{\"r\":24,\"g\":89,\"b\":208,\"a\":1}}},{\"t\":700,\"v\":{\"t\":\"c\",\"v\":{\"r\":208,\"g\":24,\"b\":67,\"a\":1}}},{\"t\":2600,\"v\":{\"t\":\"c\",\"v\":{\"r\":208,\"g\":24,\"b\":67,\"a\":1}}},{\"t\":2700,\"v\":{\"t\":\"c\",\"v\":{\"r\":24,\"g\":89,\"b\":208,\"a\":1}}}]},\"eirFfTVU8zw29\":{\"transform\":{\"data\":{\"o\":{\"x\":350,\"y\":140,\"type\":\"corner\"},\"t\":{\"x\":-3.75,\"y\":-45.03722}},\"keys\":{\"s\":[{\"t\":300,\"v\":{\"x\":0,\"y\":1}},{\"t\":600,\"v\":{\"x\":1,\"y\":1}},{\"t\":900,\"v\":{\"x\":0,\"y\":1}},{\"t\":2300,\"v\":{\"x\":0,\"y\":1}},{\"t\":2600,\"v\":{\"x\":1,\"y\":1}},{\"t\":2900,\"v\":{\"x\":0,\"y\":1}}]}},\"fill\":[{\"t\":600,\"v\":{\"t\":\"c\",\"v\":{\"r\":24,\"g\":89,\"b\":208,\"a\":1}}},{\"t\":700,\"v\":{\"t\":\"c\",\"v\":{\"r\":208,\"g\":24,\"b\":67,\"a\":1}}},{\"t\":2600,\"v\":{\"t\":\"c\",\"v\":{\"r\":208,\"g\":24,\"b\":67,\"a\":1}}},{\"t\":2700,\"v\":{\"t\":\"c\",\"v\":{\"r\":24,\"g\":89,\"b\":208,\"a\":1}}}]},\"eirFfTVU8zw30\":{\"transform\":{\"data\":{\"o\":{\"x\":350,\"y\":49.999998,\"type\":\"corner\"},\"t\":{\"x\":-3.75,\"y\":0}},\"keys\":{\"s\":[{\"t\":300,\"v\":{\"x\":0,\"y\":3.015753}},{\"t\":600,\"v\":{\"x\":1,\"y\":3.015753}},{\"t\":900,\"v\":{\"x\":0,\"y\":3.015753}},{\"t\":2300,\"v\":{\"x\":0,\"y\":3.015753}},{\"t\":2600,\"v\":{\"x\":1,\"y\":3.015753}},{\"t\":2900,\"v\":{\"x\":0,\"y\":3.015753}}]}},\"fill\":[{\"t\":600,\"v\":{\"t\":\"c\",\"v\":{\"r\":24,\"g\":89,\"b\":208,\"a\":1}}},{\"t\":700,\"v\":{\"t\":\"c\",\"v\":{\"r\":208,\"g\":24,\"b\":67,\"a\":1}}},{\"t\":2600,\"v\":{\"t\":\"c\",\"v\":{\"r\":208,\"g\":24,\"b\":67,\"a\":1}}},{\"t\":2700,\"v\":{\"t\":\"c\",\"v\":{\"r\":24,\"g\":89,\"b\":208,\"a\":1}}}]},\"eirFfTVU8zw31\":{\"transform\":{\"data\":{\"t\":{\"x\":-350,\"y\":-95.5}},\"keys\":{\"o\":[{\"t\":300,\"v\":{\"x\":350,\"y\":95.5,\"type\":\"corner\"}},{\"t\":600,\"v\":{\"x\":353.75,\"y\":95.5,\"type\":\"corner\"}},{\"t\":610,\"v\":{\"x\":346.25,\"y\":95.5,\"type\":\"corner\"}},{\"t\":900,\"v\":{\"x\":350,\"y\":95.5,\"type\":\"corner\"}},{\"t\":2300,\"v\":{\"x\":350,\"y\":95.5,\"type\":\"corner\"}},{\"t\":2600,\"v\":{\"x\":353.75,\"y\":95.5,\"type\":\"corner\"}},{\"t\":2610,\"v\":{\"x\":346.25,\"y\":95.5,\"type\":\"corner\"}},{\"t\":2900,\"v\":{\"x\":350,\"y\":95.5,\"type\":\"corner\"}}],\"s\":[{\"t\":300,\"v\":{\"x\":1,\"y\":1}},{\"t\":600,\"v\":{\"x\":0,\"y\":1}},{\"t\":900,\"v\":{\"x\":1,\"y\":1}},{\"t\":2300,\"v\":{\"x\":1,\"y\":1}},{\"t\":2600,\"v\":{\"x\":0,\"y\":1}},{\"t\":2900,\"v\":{\"x\":1,\"y\":1}}]}},\"fill\":[{\"t\":600,\"v\":{\"t\":\"c\",\"v\":{\"r\":24,\"g\":89,\"b\":208,\"a\":1}}},{\"t\":700,\"v\":{\"t\":\"c\",\"v\":{\"r\":208,\"g\":24,\"b\":67,\"a\":1}}},{\"t\":2600,\"v\":{\"t\":\"c\",\"v\":{\"r\":208,\"g\":24,\"b\":67,\"a\":1}}},{\"t\":2700,\"v\":{\"t\":\"c\",\"v\":{\"r\":24,\"g\":89,\"b\":208,\"a\":1}}}]},\"eirFfTVU8zw32\":{\"transform\":{\"data\":{\"t\":{\"x\":-350,\"y\":-95.5}},\"keys\":{\"o\":[{\"t\":300,\"v\":{\"x\":350,\"y\":95.5,\"type\":\"corner\"}},{\"t\":600,\"v\":{\"x\":346.25,\"y\":95.5,\"type\":\"corner\"}},{\"t\":610,\"v\":{\"x\":353.75,\"y\":95.5,\"type\":\"corner\"}},{\"t\":900,\"v\":{\"x\":350,\"y\":95.5,\"type\":\"corner\"}},{\"t\":2300,\"v\":{\"x\":350,\"y\":95.5,\"type\":\"corner\"}},{\"t\":2600,\"v\":{\"x\":346.25,\"y\":95.5,\"type\":\"corner\"}},{\"t\":2610,\"v\":{\"x\":353.75,\"y\":95.5,\"type\":\"corner\"}},{\"t\":2900,\"v\":{\"x\":350,\"y\":95.5,\"type\":\"corner\"}}],\"s\":[{\"t\":300,\"v\":{\"x\":1,\"y\":1}},{\"t\":600,\"v\":{\"x\":0,\"y\":1}},{\"t\":900,\"v\":{\"x\":1,\"y\":1}},{\"t\":2300,\"v\":{\"x\":1,\"y\":1}},{\"t\":2600,\"v\":{\"x\":0,\"y\":1}},{\"t\":2900,\"v\":{\"x\":1,\"y\":1}}]}},\"fill\":[{\"t\":600,\"v\":{\"t\":\"g\",\"s\":[{\"c\":{\"r\":50,\"g\":155,\"b\":238,\"a\":1},\"o\":0},{\"c\":{\"r\":47,\"g\":107,\"b\":217,\"a\":1},\"o\":1}],\"r\":\"eirFfTVU8zw32-fill\",\"gt\":[1,0,0,1,0,0],\"f\":{\"x\":0.5,\"y\":0.001867},\"to\":{\"x\":0.5,\"y\":1}}},{\"t\":700,\"v\":{\"t\":\"g\",\"s\":[{\"c\":{\"r\":255,\"g\":97,\"b\":113,\"a\":1},\"o\":0},{\"c\":{\"r\":250,\"g\":28,\"b\":91,\"a\":1},\"o\":1}],\"r\":\"eirFfTVU8zw32-fill\",\"gt\":[1,0,0,1,0,0],\"f\":{\"x\":0.5,\"y\":0.001867},\"to\":{\"x\":0.5,\"y\":1}}},{\"t\":2600,\"v\":{\"t\":\"g\",\"s\":[{\"c\":{\"r\":255,\"g\":97,\"b\":113,\"a\":1},\"o\":0},{\"c\":{\"r\":250,\"g\":28,\"b\":91,\"a\":1},\"o\":1}],\"r\":\"eirFfTVU8zw32-fill\",\"gt\":[1,0,0,1,0,0],\"f\":{\"x\":0.5,\"y\":0.001867},\"to\":{\"x\":0.5,\"y\":1}}},{\"t\":2700,\"v\":{\"t\":\"g\",\"s\":[{\"c\":{\"r\":50,\"g\":155,\"b\":238,\"a\":1},\"o\":0},{\"c\":{\"r\":47,\"g\":107,\"b\":217,\"a\":1},\"o\":1}],\"r\":\"eirFfTVU8zw32-fill\",\"gt\":[1,0,0,1,0,0],\"f\":{\"x\":0.5,\"y\":0.001867},\"to\":{\"x\":0.5,\"y\":1}}}]}},\"s\":\"MDOA1MzljNDM4NNTk2OTM4Mjk1POGE5MDhmNDMG1YjU0NTNYNTQE1MTRkNDM4NSThhOTM4Njg0KOTU4YTkwOGYS0M0s1YjUyNGIQ0MzhhOTU4NEjkzODI5NThhLVjkwOGY5NDQNzNWI1MVY0ZDJQzODc4YUE4ZCDhkNDM1Yk81AMjRkNDM4MjhWkOTU4NlQ5MzXhmODI5NTg2NSDM1Yjg3ODJETOGQ5NDg2NGQB0Mzk0OTE4NjNg2ODU0M0w1YCjUyOWU\/\"}],\"options\":\"MDMAxMDgyMjk3YETdiNjg3OTdiIMjk0MTI5NzMD3NjY4NmIyOTUg0\"},'__SVGATOR_PLAYER__',window)]]><\/script><\/svg>";
    String fileText = SVGatorPlayer.wrapPage(Svg);
    String dataUrl = Uri.dataFromString(
        fileText,
        mimeType: 'text/html',
        encoding: Encoding.getByName('utf-8')
    ).toString();
    webViewController.loadUrl(dataUrl);
  }
}
